#!/usr/bin/env bash
TRPROGNAME=$(printf $1 | tr - _)
cat > $1/src/Makefile.am <<EOF
bin_PROGRAMS = $1
${TRPROGNAME}_SOURCES = main.c
EOF
